@@ -21,7 +21,6 @@ extern "C" {
 #define AMDXDNA_DRIVER_MAJOR 1
 #define AMDXDNA_DRIVER_MINOR 0
 
-#define AMDXDNA_INVALID_CMD_HANDLE (~0UL)
 #define AMDXDNA_INVALID_ADDR (~0UL)
 #define AMDXDNA_INVALID_CTX_HANDLE 0
 #define AMDXDNA_INVALID_BO_HANDLE 0
@@ -50,11 +49,9 @@ enum amdxdna_drm_ioctl_id {
   DRM_AMDXDNA_GET_BO_INFO,
   DRM_AMDXDNA_SYNC_BO,
   DRM_AMDXDNA_EXEC_CMD,
-  DRM_AMDXDNA_WAIT_CMD,
   DRM_AMDXDNA_GET_INFO,
   DRM_AMDXDNA_SET_STATE,
-  DRM_AMDXDNA_SUBMIT_WAIT,
-  DRM_AMDXDNA_SUBMIT_SIGNAL,
+  DRM_AMDXDNA_WAIT_CMD,
   DRM_AMDXDNA_NUM_IOCTLS
 };
 
@@ -96,6 +93,7 @@ struct amdxdna_qos_info {
  * @mem_size: Size of AIE tile memory.
  * @umq_doorbell: Returned offset of doorbell associated with UMQ.
  * @handle: Returned hardware context handle.
+ * @pad: Structure padding.
  */
 struct amdxdna_drm_create_hwctx {
   __u64 ext;
@@ -108,12 +106,13 @@ struct amdxdna_drm_create_hwctx {
   __u32 mem_size;
   __u32 umq_doorbell;
   __u32 handle;
+  __u32 pad;
 };
 
 /**
  * struct amdxdna_drm_destroy_hwctx - Destroy hardware context.
  * @handle: Hardware context handle.
- * @pad: MBZ.
+ * @pad: Structure padding.
  */
 struct amdxdna_drm_destroy_hwctx {
   __u32 handle;
@@ -122,9 +121,9 @@ struct amdxdna_drm_destroy_hwctx {
 
 /**
  * struct amdxdna_cu_config - configuration for one CU
- * @cu_bo: CU configuration buffer bo handle
- * @cu_func: Functional of a CU
- * @pad: MBZ
+ * @cu_bo: CU configuration buffer bo handle.
+ * @cu_func: Function of a CU.
+ * @pad: Structure padding.
  */
 struct amdxdna_cu_config {
   __u32 cu_bo;
@@ -135,9 +134,9 @@ struct amdxdna_cu_config {
 /**
  * struct amdxdna_hwctx_param_config_cu - configuration for CUs in hardware
  * context
- * @num_cus: Number of CUs to configure
- * @pad: MBZ
- * @cu_configs: Array of CU configurations of struct amdxdna_cu_config
+ * @num_cus: Number of CUs to configure.
+ * @pad: Structure padding.
+ * @cu_configs: Array of CU configurations of struct amdxdna_cu_config.
  */
 struct amdxdna_hwctx_param_config_cu {
   __u16 num_cus;
@@ -160,6 +159,7 @@ enum amdxdna_drm_config_hwctx_param {
  * @param_val: A structure specified by the param_type struct member.
  * @param_val_size: Size of the parameter buffer pointed to by the param_val.
  *		    If param_val is not a pointer, driver can ignore this.
+ * @pad: Structure padding.
  *
  * Note: if the param_val is a pointer pointing to a buffer, the maximum size
  * of the buffer is 4KiB(PAGE_SIZE).
@@ -191,17 +191,16 @@ enum amdxdna_bo_type {
 /**
  * struct amdxdna_drm_create_bo - Create a buffer object.
  * @flags: Buffer flags. MBZ.
- * @type: Buffer type.
  * @vaddr: User VA of buffer if applied. MBZ.
  * @size: Size in bytes.
+ * @type: Buffer type.
  * @handle: Returned DRM buffer object handle.
  */
 struct amdxdna_drm_create_bo {
   __u64 flags;
-  __u32 type;
-  __u32 _pad;
   __u64 vaddr;
   __u64 size;
+  __u32 type;
   __u32 handle;
 };
 
@@ -210,6 +209,7 @@ struct amdxdna_drm_create_bo {
  * @ext: MBZ.
  * @ext_flags: MBZ.
  * @handle: DRM buffer object handle.
+ * @pad: Structure padding.
  * @map_offset: Returned DRM fake offset for mmap().
  * @vaddr: Returned user VA of buffer. 0 in case user needs mmap().
  * @xdna_addr: Returned XDNA device virtual address.
@@ -218,7 +218,7 @@ struct amdxdna_drm_get_bo_info {
   __u64 ext;
   __u64 ext_flags;
   __u32 handle;
-  __u32 _pad;
+  __u32 pad;
   __u64 map_offset;
   __u64 vaddr;
   __u64 xdna_addr;
@@ -252,8 +252,8 @@ enum amdxdna_cmd_type {
  * @ext_flags: MBZ.
  * @hwctx: Hardware context handle.
  * @type: One of command type in enum amdxdna_cmd_type.
- * @cmd_handles: Array of command handles or the command handle itself in case
- * of just one.
+ * @cmd_handles: Array of command handles or the command handle itself
+ * in case of just one.
  * @args: Array of arguments for all command handles.
  * @cmd_count: Number of command handles in the cmd_handles array.
  * @arg_count: Number of arguments in the args array.
@@ -279,8 +279,6 @@ struct amdxdna_drm_exec_cmd {
  * @seq: sequence number of the command returned by execute command.
  *
  * Wait a command specified by seq to be completed.
- * Using AMDXDNA_INVALID_CMD_HANDLE as seq means wait till there is a free slot
- * to submit a new command.
  */
 struct amdxdna_drm_wait_cmd {
   __u32 hwctx;
@@ -290,10 +288,9 @@ struct amdxdna_drm_wait_cmd {
 
 /**
  * struct amdxdna_drm_query_aie_status - Query the status of the AIE hardware
- * @buffer: The user space buffer that will return the AIE status
- * @buffer_size: The size of the user space buffer
- * @cols_filled: A bitmap of AIE columns whose data has been returned in the
- * buffer.
+ * @buffer: The user space buffer that will return the AIE status.
+ * @buffer_size: The size of the user space buffer.
+ * @cols_filled: A bitmap of AIE columns whose data has been returned in the buffer.
  */
 struct amdxdna_drm_query_aie_status {
   __u64 buffer;      /* out */
@@ -303,8 +300,8 @@ struct amdxdna_drm_query_aie_status {
 
 /**
  * struct amdxdna_drm_query_aie_version - Query the version of the AIE hardware
- * @major: The major version number
- * @minor: The minor version number
+ * @major: The major version number.
+ * @minor: The minor version number.
  */
 struct amdxdna_drm_query_aie_version {
   __u32 major; /* out */
@@ -319,7 +316,7 @@ struct amdxdna_drm_query_aie_version {
  * @dma_channel_count: The number of dma channels.
  * @lock_count: The number of locks.
  * @event_reg_count: The number of events.
- * @pad: MBZ.
+ * @pad: Structure padding.
  */
 struct amdxdna_drm_query_aie_tile_metadata {
   __u16 row_count;
@@ -331,8 +328,7 @@ struct amdxdna_drm_query_aie_tile_metadata {
 };
 
 /**
- * struct amdxdna_drm_query_aie_metadata - Query the metadata of the AIE
- * hardware
+ * struct amdxdna_drm_query_aie_metadata - Query the metadata of the AIE hardware
  * @col_size: The size of a column in bytes.
  * @cols: The total number of columns.
  * @rows: The total number of rows.
@@ -355,7 +351,7 @@ struct amdxdna_drm_query_aie_metadata {
  * struct amdxdna_drm_query_clock - Metadata for a clock
  * @name: The clock name.
  * @freq_mhz: The clock frequency.
- * @pad: MBZ.
+ * @pad: Structure padding.
  */
 struct amdxdna_drm_query_clock {
   __u8 name[16];
@@ -381,14 +377,12 @@ enum amdxdna_sensor_type { AMDXDNA_SENSOR_TYPE_POWER };
  * @input: The current value of the sensor.
  * @max: The maximum value possible for the sensor.
  * @average: The average value of the sensor.
- * @highest: The highest recorded sensor value for this driver load for the
- * sensor.
+ * @highest: The highest recorded sensor value for this driver load for the sensor.
  * @status: The sensor status.
  * @units: The sensor units.
- * @unitm: Translates value member variables into the correct unit via (pow(10,
- * unitm) * value)
- * @type: The sensor type from enum amdxdna_sensor_type
- * @pad: MBZ.
+ * @unitm: Translates value member variables into the correct unit via (pow(10, unitm) * value).
+ * @type: The sensor type from enum amdxdna_sensor_type.
+ * @pad: Structure padding.
  */
 struct amdxdna_drm_query_sensor {
   __u8 label[64];
@@ -408,14 +402,14 @@ struct amdxdna_drm_query_sensor {
  * @context_id: The ID for this context.
  * @start_col: The starting column for the partition assigned to this context.
  * @num_col: The number of columns in the partition assigned to this context.
+ * @pad: Structure padding.
  * @pid: The Process ID of the process that created this context.
  * @command_submissions: The number of commands submitted to this context.
  * @command_completions: The number of commands completed by this context.
- * @migrations: The number of times this context has been moved to a different
- * partition.
- * @preemptions: The number of times this context has been preempted by another
- * context in the same partition.
- * @pad: MBZ.
+ * @migrations: The number of times this context has been moved to a different partition.
+ * @preemptions: The number of times this context has been preempted by another context in the
+ *               same partition.
+ * @errors: The errors for this context.
  */
 struct amdxdna_drm_query_hwctx {
   __u32 context_id;
@@ -471,6 +465,7 @@ enum amdxdna_power_mode_type {
   POWER_MODE_LOW,     /**< Set frequency to lowest DPM */
   POWER_MODE_MEDIUM,  /**< Set frequency to medium DPM */
   POWER_MODE_HIGH,    /**< Set frequency to highest DPM */
+  POWER_MODE_TURBO,   /**< More power, more performance */
 };
 
 /**
@@ -508,13 +503,13 @@ enum amdxdna_drm_get_param {
   DRM_AMDXDNA_READ_AIE_REG,
   DRM_AMDXDNA_QUERY_FIRMWARE_VERSION,
   DRM_AMDXDNA_GET_POWER_MODE,
+  DRM_AMDXDNA_QUERY_TELEMETRY,
   DRM_AMDXDNA_NUM_GET_PARAM,
 };
 
 /**
  * struct amdxdna_drm_get_info - Get some information from the AIE hardware.
- * @param: Value in enum amdxdna_drm_get_param. Specifies the structure passed
- * in the buffer.
+ * @param: Value in enum amdxdna_drm_get_param. Specifies the structure passed in the buffer.
  * @buffer_size: Size of the input buffer. Size needed/written by the kernel.
  * @buffer: A structure specified by the param struct member.
  */
@@ -542,10 +537,8 @@ enum amdxdna_drm_set_param {
 };
 
 /**
- * struct amdxdna_drm_set_state - Set the state of some component within the AIE
- * hardware.
- * @param: Value in enum amdxdna_drm_set_param. Specifies the structure passed
- * in the buffer.
+ * struct amdxdna_drm_set_state - Set the state of some component within the AIE hardware.
+ * @param: Value in enum amdxdna_drm_set_param. Specifies the structure passed in the buffer.
  * @buffer_size: Size of the input buffer.
  * @buffer: A structure specified by the param struct member.
  */
@@ -555,63 +548,35 @@ struct amdxdna_drm_set_state {
   __u64 buffer;      /* in */
 };
 
-/**
- * struct amdxdna_drm_syncobjs - Signal or wait on array of DRM timelined sync
- * objects.
- * @handles: Array of handles of sync objects.
- * @points: Array of time points for each sync objects.
- * @count: Number of elements in the above array.
- */
-struct amdxdna_drm_syncobjs {
-  __u64 handles; /* in */
-  __u64 points;  /* in */
-  __u32 count;   /* in */
-  __u32 pad;
-};
+#define DRM_IOCTL_AMDXDNA_CREATE_HWCTX                                                             \
+  DRM_IOWR(DRM_COMMAND_BASE + DRM_AMDXDNA_CREATE_HWCTX, struct amdxdna_drm_create_hwctx)
 
-#define DRM_IOCTL_AMDXDNA_CREATE_HWCTX                                         \
-  DRM_IOWR(DRM_COMMAND_BASE + DRM_AMDXDNA_CREATE_HWCTX,                        \
-           struct amdxdna_drm_create_hwctx)
+#define DRM_IOCTL_AMDXDNA_DESTROY_HWCTX                                                            \
+  DRM_IOWR(DRM_COMMAND_BASE + DRM_AMDXDNA_DESTROY_HWCTX, struct amdxdna_drm_destroy_hwctx)
 
-#define DRM_IOCTL_AMDXDNA_DESTROY_HWCTX                                        \
-  DRM_IOWR(DRM_COMMAND_BASE + DRM_AMDXDNA_DESTROY_HWCTX,                       \
-           struct amdxdna_drm_destroy_hwctx)
+#define DRM_IOCTL_AMDXDNA_CONFIG_HWCTX                                                             \
+  DRM_IOWR(DRM_COMMAND_BASE + DRM_AMDXDNA_CONFIG_HWCTX, struct amdxdna_drm_config_hwctx)
 
-#define DRM_IOCTL_AMDXDNA_CONFIG_HWCTX                                         \
-  DRM_IOWR(DRM_COMMAND_BASE + DRM_AMDXDNA_CONFIG_HWCTX,                        \
-           struct amdxdna_drm_config_hwctx)
+#define DRM_IOCTL_AMDXDNA_CREATE_BO                                                                \
+  DRM_IOWR(DRM_COMMAND_BASE + DRM_AMDXDNA_CREATE_BO, struct amdxdna_drm_create_bo)
 
-#define DRM_IOCTL_AMDXDNA_CREATE_BO                                            \
-  DRM_IOWR(DRM_COMMAND_BASE + DRM_AMDXDNA_CREATE_BO,                           \
-           struct amdxdna_drm_create_bo)
+#define DRM_IOCTL_AMDXDNA_GET_BO_INFO                                                              \
+  DRM_IOWR(DRM_COMMAND_BASE + DRM_AMDXDNA_GET_BO_INFO, struct amdxdna_drm_get_bo_info)
 
-#define DRM_IOCTL_AMDXDNA_GET_BO_INFO                                          \
-  DRM_IOWR(DRM_COMMAND_BASE + DRM_AMDXDNA_GET_BO_INFO,                         \
-           struct amdxdna_drm_get_bo_info)
-
-#define DRM_IOCTL_AMDXDNA_SYNC_BO                                              \
+#define DRM_IOCTL_AMDXDNA_SYNC_BO                                                                  \
   DRM_IOWR(DRM_COMMAND_BASE + DRM_AMDXDNA_SYNC_BO, struct amdxdna_drm_sync_bo)
 
-#define DRM_IOCTL_AMDXDNA_EXEC_CMD                                             \
+#define DRM_IOCTL_AMDXDNA_EXEC_CMD                                                                 \
   DRM_IOWR(DRM_COMMAND_BASE + DRM_AMDXDNA_EXEC_CMD, struct amdxdna_drm_exec_cmd)
 
-#define DRM_IOCTL_AMDXDNA_WAIT_CMD                                             \
+#define DRM_IOCTL_AMDXDNA_WAIT_CMD                                                                 \
   DRM_IOWR(DRM_COMMAND_BASE + DRM_AMDXDNA_WAIT_CMD, struct amdxdna_drm_wait_cmd)
 
-#define DRM_IOCTL_AMDXDNA_GET_INFO                                             \
+#define DRM_IOCTL_AMDXDNA_GET_INFO                                                                 \
   DRM_IOWR(DRM_COMMAND_BASE + DRM_AMDXDNA_GET_INFO, struct amdxdna_drm_get_info)
 
-#define DRM_IOCTL_AMDXDNA_SET_STATE                                            \
-  DRM_IOWR(DRM_COMMAND_BASE + DRM_AMDXDNA_SET_STATE,                           \
-           struct amdxdna_drm_set_state)
-
-#define DRM_IOCTL_AMDXDNA_SUBMIT_WAIT                                          \
-  DRM_IOWR(DRM_COMMAND_BASE + DRM_AMDXDNA_SUBMIT_WAIT,                         \
-           struct amdxdna_drm_syncobjs)
-
-#define DRM_IOCTL_AMDXDNA_SUBMIT_SIGNAL                                        \
-  DRM_IOWR(DRM_COMMAND_BASE + DRM_AMDXDNA_SUBMIT_SIGNAL,                       \
-           struct amdxdna_drm_syncobjs)
+#define DRM_IOCTL_AMDXDNA_SET_STATE                                                                \
+  DRM_IOWR(DRM_COMMAND_BASE + DRM_AMDXDNA_SET_STATE, struct amdxdna_drm_set_state)
 
 #if defined(__cplusplus)
 } /* extern c end */
