@@ -43,6 +43,7 @@
 #ifndef HSA_RUNTIME_CORE_INC_THUNK_LOADER_H
 #define HSA_RUNTIME_CORE_INC_THUNK_LOADER_H
 
+#include <string>
 #include <amdgpu.h>
 #include "hsakmt/hsakmttypes.h"
 
@@ -319,6 +320,13 @@ class ThunkLoader {
     typedef HSAKMT_STATUS (HSAKMT_DEF(hsaKmtPcSamplingSupport))(void);
     typedef HSAKMT_STATUS (HSAKMT_DEF(hsaKmtModelEnabled))(bool* enable);
     typedef HSAKMT_STATUS (HSAKMT_DEF(hsaKmtQueueRingDoorbell))(HSA_QUEUEID QueueId);
+    typedef HSAKMT_STATUS (HSAKMT_DEF(hsaKmtAisReadWriteFile))(void *devicePtr, \
+                                      HSAuint64 size, \
+                                      HSAint32 fd, \
+                                      HSAint64 file_offset, \
+                                      HsaAisFlags flags, \
+                                      HSAuint64 *SizeCopiedInBytes, \
+                                      HSAint32 *status);
 
     /* drm API */
     typedef int (DRM_DEF(amdgpu_device_initialize))(int fd, \
@@ -363,6 +371,10 @@ class ThunkLoader {
     void LoadThunkApiTable();
     bool CreateThunkInstance();
     bool DestroyThunkInstance();
+    bool IsDXG() const { return is_dxg_; }
+    bool IsDTIF() const { return is_dtif_; }
+    bool IsSharedLibraryLoaded() const { return is_loaded_; }
+    void* ThunkHandle() const { return thunk_handle; }
 
     HSAKMT_DEF(hsaKmtOpenKFD)* HSAKMT_PFN(hsaKmtOpenKFD);
     HSAKMT_DEF(hsaKmtCloseKFD)* HSAKMT_PFN(hsaKmtCloseKFD);
@@ -456,6 +468,7 @@ class ThunkLoader {
     HSAKMT_DEF(hsaKmtPcSamplingSupport)* HSAKMT_PFN(hsaKmtPcSamplingSupport);
     HSAKMT_DEF(hsaKmtModelEnabled)* HSAKMT_PFN(hsaKmtModelEnabled);
     HSAKMT_DEF(hsaKmtQueueRingDoorbell)* HSAKMT_PFN(hsaKmtQueueRingDoorbell);
+    HSAKMT_DEF(hsaKmtAisReadWriteFile)* HSAKMT_PFN(hsaKmtAisReadWriteFile);
 
     DRM_DEF(amdgpu_device_initialize)* DRM_PFN(amdgpu_device_initialize);
     DRM_DEF(amdgpu_device_deinitialize)* DRM_PFN(amdgpu_device_deinitialize);
@@ -468,7 +481,12 @@ class ThunkLoader {
     DRM_DEF(drmCommandWriteRead)* DRM_PFN(drmCommandWriteRead);
 
   private:
-    void *dtif_handle;
+    std::string whoami();
+    void *thunk_handle;
+    std::string library_name;
+    bool is_dxg_;
+    bool is_dtif_;
+    bool is_loaded_;
 };
 
 }   //  namespace core
